@@ -408,5 +408,5 @@ unsigned char DisparityNodelet::colormap[768] =
 } // namespace image_view
 
 // Register the nodelet
-#include <pluginlib/class_list_macros.h>
+#include <pluginlib/class_list_macros.hpp>
 PLUGINLIB_EXPORT_CLASS( image_view::DisparityNodelet, nodelet::Nodelet)
